<?php

namespace Drupal\opensign\App;

use Drupal\Core\Database\Connection;
use Drupal\Core\Session\AccountInterface;
use GuzzleHttp\Client;
use GuzzleHttp\Exception\RequestException;
use Symfony\Component\DependencyInjection\ContainerInterface;

class LoginHandler {

  protected $currentUser;

  protected $connection;

  /**
   * {@inheritdoc}
   */
  public function __construct(
    AccountInterface $current_user,
    Connection $connection
  ) {
    $this->currentUser = $current_user;
    $this->connection = $connection;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('current_user'),
      $container->get('database')
    );
  }

  public function login() {
    $config = \Drupal::config('opensign.server_settings');
    $tempstore = \Drupal::service('tempstore.private');
    $store = $tempstore->get('opensign_collection');

    $login_data = $store->get('login_data');
    if (empty($login_data)) {
      try {

        $uid = $this->currentUser->id();
        $query = $this->connection->select('opensign_user', 'o')
          ->condition('o.uid', $uid, '=')
          ->fields('o', ['uid', 'opensign_email', 'opensign_password']);
        $result = $query->execute()->fetchAssoc();

        if (!empty($result)) {
          $headers = [
            'Content-Type' => 'application/json',
            'X-Parse-Application-Id' => $config->get('opensign_app_id'),
            'X-Parse-REST-API-Key' => $config->get('opensign_rest_api_token')
          ];
          $httpClient = new Client(['headers' => $headers]);

          $response = $httpClient->request('POST', $config->get('opensign_server_url') . '/login', [
            'form_params' => [
              'username' => $result['opensign_email'],
              'password' => $result['opensign_password'],
            ]
          ]);

          $response_data = json_decode($response->getBody()->getContents(), TRUE);
          $login_data = $response_data;
          // Set the key/value pair.
          $store->set('login_data', $login_data);
          return $login_data;
        }
      } catch(Exception $e) {
        // Exception handling
      }
    }
    return $login_data;

  }
}